package com.nisum.attendance.attendance.controller;

import com.nisum.attendance.attendance.exceptions.ResourceNotFoundException;
import com.nisum.attendance.attendance.model.Attendance;
import com.nisum.attendance.attendance.repository.AttendanceRepository;
import com.nisum.attendance.attendance.service.AttendanceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@CrossOrigin(origins = "*")
@RestController
@RequestMapping("/api")
public class AttendanceController {
    @Autowired AttendanceService attendanceService;

    @GetMapping("/attendance")
    public List<Attendance> getAllAttendances() {
        return attendanceService.findAllAttendance();
    }

    @GetMapping("/attendance/{id}")
    public ResponseEntity<Attendance> getAttendance(@PathVariable(value = "id") Long attendanceId) throws ResourceNotFoundException {
        Attendance attendance = attendanceService.getAttendanceById(attendanceId)
                .orElseThrow(() -> new ResourceNotFoundException("Attendance records by id not found." + attendanceId));
        return ResponseEntity.ok(attendance);
    }

    @PostMapping("/attendance")
    public Attendance createAttendance(@Valid @RequestBody Attendance attendance) {
        return attendanceService.addAttendance(attendance);
    }

    @PutMapping("/attendance/{id}")
    public ResponseEntity<Attendance> updateAttendance(@PathVariable(value = "id") Long attendanceId,
                                                       @Valid @RequestBody Attendance attendanceDetails) {
        Attendance updatedAttendance = attendanceService.updateAttendance(attendanceId, attendanceDetails);
        return ResponseEntity.ok(updatedAttendance);
    }
}
